@@ -1025,8 +1025,14 @@ class DataVars(object):
 ##############################################################################
 class glob_attr:
     """Глобальные аттрибуты для методов заполнения переменных"""
-    path_env = cl_utils.getpathenv()
 
-    def _runos(self,cmd,ret_first=None):
+    def _runos(self,cmd, ret_first=None, env={}):
         """Вернуть результат выполнения команды ОС"""
-        return cl_utils.runOsCommand(cmd, None, ret_first)
+        if not env:
+            envDict = {}
+            env.update(os.environ.items() + [("PATH",cl_utils.getpathenv())] +\
+                       env.items())
+        retCode, programOut = cl_utils.runOsCommand(cmd, None, ret_first, env)
+        if not retCode:
+            return programOut
+        return False
