@@ -23,21 +23,17 @@
 
 class Data:
 
-    ##имя компьютера
-    #net_host
+    # имя компьютера
     os_net_hostname = {'mode':"w"}
-
-    ##текущая сеть
     # разрешенные сети
-    #net_networks
-    os_net_allow =      {}
+    os_net_allow ={}
+    # ip на всех интерфейсах
+    os_net_ip ={}
 
-    ##короткое название системы (CLD)
-    #setup_sys_shortname
+    #короткое название системы (CLD)
     os_linux_shortname={}
 
-    ##домен
-    #sys_domain
+    #домен
     os_net_domain = {'mode':"w"}
 
     # Пути к ini файлам
@@ -84,3 +80,9 @@ class Data:
 
     # версия системы
     os_linux_ver = {}
+
+    # Тип профиля
+    cl_pass_type = {'mode':"w"}
+
+    # Действие программы 
+    cl_pass_run = {'mode':"w"}
